<?php
/**
 * Amazon Auto Links
 *
 * Generates links of Amazon products just coming out today. You just pick categories and they appear even in JavaScript disabled browsers.
 *
 * https://en.michaeluno.jp/amazon-auto-links/
 * Copyright (c) 2013-2021 Michael Uno
 */

/**
 * Activates a template by a template id
 *
 * @since       3.7.4
 */
class AmazonAutoLinks_Template_Event_Action_ActivationStatus extends AmazonAutoLinks_PluginUtility {

    /**
     * @var     array
     * @since   4.6.7
     */
    private $___aToggledTemplateNames = array();

    public function __construct() {

        add_action( 'aal_action_activate_templates', array( $this, 'replyToActivateTemplates' ), 10 );
        add_action( 'aal_action_deactivate_templates', array( $this, 'replyToDeactivateTemplates' ), 10 );

    }

    /**
     * @param array an array holding template IDs or template option arrays.
     * This is sed for an addon to register new template with activated. The template list table's actions use this as true. true: yes, false: no.
     */
    public function replyToActivateTemplates( array $aTemplateIDs ) {
        $this->___getTemplatesStatusToggled( $aTemplateIDs, true );
    }
    /**
     * @param array an array holding template IDs or template option arrays.
     */
    public function replyToDeactivateTemplates( array $aTemplateIDs ) {
        $this->___getTemplatesStatusToggled( $aTemplateIDs, false );
    }

        /**
         * @param array $aTemplateIDs
         * @param boolean $bActivate true for activation; false for deactivation
         */
        private function ___getTemplatesStatusToggled( array $aTemplateIDs, $bActivate ) {
            $_oTemplateOption = AmazonAutoLinks_TemplateOption::getInstance();
            $_aTemplates      = $this->getAsArray( $_oTemplateOption->get() );
            foreach( $aTemplateIDs as $_sTemplateID ) {
                $_aTemplates = $this->___getTemplateStatusToggled( $_sTemplateID, $_aTemplates, $bActivate );
            }
            $_oTemplateOption->aOptions = $_aTemplates;
            $_oTemplateOption->save();

            $this->___setSettingNoticeOfToggleTemplates( $bActivate );
        }
            /**
             * @param boolean $bActivate
             * @since 4.6.7
             */
            private function ___setSettingNoticeOfToggleTemplates( $bActivate ) {
                $this->___aToggledTemplateNames = array_filter( $this->___aToggledTemplateNames ); // drop non-true values
                $_aTemplateNames = implode( ', ', $this->___aToggledTemplateNames );
                $_sMessage       = $bActivate
                    ? sprintf( __( 'The template, %1$s, has been activated.', 'amazon-auto-links' ), $_aTemplateNames )
                    : sprintf( __( 'The template, %1$s, has been deactivated.', 'amazon-auto-links' ), $_aTemplateNames );
                do_action( 'aal_action_set_admin_setting_notice', $_sMessage, 'updated' );
            }
            /**
             * @param  string   $sID            The passed templated ID.
             * @param  array    $aTemplates
             * @param  boolean  $bActivate
             * @return array
             */
            private function ___getTemplateStatusToggled( $sID, array $aTemplates, $bActivate ) {

                $_oTemplateOption   = AmazonAutoLinks_TemplateOption::getInstance();

                if ( isset( $aTemplates[ $sID ] ) && $_oTemplateOption->exists( $sID ) ) {
                    return $this->___getTemplatesWithUpdatedActivationStatus( $aTemplates, $sID, $bActivate, $_oTemplateOption );
                }

                // At this point, an un-stored template is given.

                // The id may be a relative path of the template directory
                $_sDirPath = $this->getAbsolutePathFromRelative( $sID );
                if ( ! file_exists( $_sDirPath ) ) {
                    $_aErrorInfo = array(
                        'template_id' => $sID,
                        'dir_path'    => $_sDirPath,
                        'activate'    => $bActivate,
                    );
                    $_sMessage = __( 'The given template does not exist so could not toggle the activation status.', 'amazon-auto-links' );
                    new AmazonAutoLinks_Error( 'TEMPLATE_ACTIVATION_STATUS', $_sMessage, $_aErrorInfo, false );
                    do_action( 'aal_action_set_admin_setting_notice', $_sMessage, 'error' );
                    return $aTemplates;
                }

                $_aTemplate         = $_oTemplateOption->getTemplateArrayByDirPath( $_sDirPath );
                $_sTemplateID       = $_aTemplate[ 'id' ];
                $aTemplates[ $_sTemplateID ] = array(
                    'is_active' => $bActivate,
                ) + $this->getAsArray( $_aTemplate );
                $this->___aToggledTemplateNames[] = $this->getElement( $_aTemplate, 'name' );
                return $aTemplates;

            }
                /**
                 * @param  array     $aTemplates
                 * @param  string    $sTemplateID
                 * @param  boolean   $bActivate
                 * @param  AmazonAutoLinks_TemplateOption $oTemplateOption
                 * @return array
                 * @since  4.6.7
                 */
                private function ___getTemplatesWithUpdatedActivationStatus( array $aTemplates, $sTemplateID, $bActivate, $oTemplateOption ) {
                    $_aTemplate         = array();
                    // @since 3.10.0 If activating, renew the template information.
                    if ( $bActivate ) {
                        $_sDirPath  = $this->getAbsolutePathFromRelative( $sTemplateID );
                        $_aTemplate = file_exists( $_sDirPath )
                            ? $oTemplateOption->getTemplateArrayByDirPath( $_sDirPath )
                            : array();
                        $_aTemplate = $this->getAsArray( $_aTemplate );
                    }

                    $_aTemplate = array(
                        'is_active' => $bActivate,
                    )
                        + $_aTemplate
                        + $this->getElementAsArray( $aTemplates, $sTemplateID );

                    $this->___aToggledTemplateNames[] = $this->getElement( $_aTemplate, 'name' );

                    $aTemplates[ $sTemplateID ] = $_aTemplate;
                    return $aTemplates;
                }

}